Module sort

Module sort 

Regroups some classic sort algorithms

Structs

BinaryHeapSort
Implementation of binary heap sort with the standard library
HeapSort
Implementation of heap sort relatively from scratch using a max oriented binary heap
InsertionSort
Implementation of insertion sort algorithm.
MergeSort
Implementation of merge sort algorithm.
QuickSort
Implementation of quick sort algorithm

Enums

MergeSortAlgorithm
Enumerating the different types of merge sort algorithm